@@ -187,7 +187,7 @@ yes""" % d
             ret.update(self._generate_intermediate(cn, with_ca=with_ca))
 
         self.dbg('Generating key for %s: %s' % (cn, ret['priv']['pem']))
-        self.exec_cmd('openssl genrsa -des3 -passout "pass:%s" -out "%s" 2048' %  # noqa: E501
+        self.exec_cmd('openssl genpkey -algorithm RSA -pass "pass:%s" -out "%s"' %  # noqa: E501
                       (password, ret['priv']['pem']))
 
         self.dbg('Generating request for %s: %s' % (cn, ret['req']))
@@ -247,7 +247,7 @@ yes""" % d
 
         self.dbg('Generating key for %s intermediate: %s' %
                  (cn, ret['intermediate_priv']['pem']))
-        self.exec_cmd('openssl genrsa -out "%s" 2048' %  # noqa: E501
+        self.exec_cmd('openssl genpkey -algorithm RSA -out "%s"' %  # noqa: E501
                     (ret['intermediate_priv']['pem']))
         self.dbg('Generating request for %s: %s' %
                  (cn, ret['intermediate_req']))
@@ -288,7 +288,7 @@ yes""" % d
             ['-certfile "{}"'.format(c) for c in additional_certs_for_pkcs12])
 
         self.dbg('Creating PKCS#12 for %s in %s' % (cn, ret['pkcs']))
-        self.exec_cmd('openssl pkcs12 -export -out "%s" -inkey "%s" -in "%s"  %s -passin "pass:%s" -passout "pass:%s"' %  # noqa: E501
+        self.exec_cmd('openssl pkcs12 -export -descert -out "%s" -inkey "%s" -in "%s"  %s -passin "pass:%s" -passout "pass:%s"' %  # noqa: E501
                       (ret['pkcs'],
                        ret['priv']['pem'],
                        ret['pub']['pem'],
